@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2010-2013 Johannes Dewender
+# Copyright (C) 2009-2015 Johannes Dewender
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ The project is hosted on
 https://github.com/JonnyJD/musicbrainz-isrcsubmit
 """
 
-__version__ = "2.0.0"
+__version__ = "2.0.1"
 AGENT_NAME = "isrcsubmit.py"
 DEFAULT_SERVER = "musicbrainz.org"
 # starting with highest priority
@@ -369,7 +369,7 @@ def find_backend():
     if backend is None:
         print_error("Cannot find a backend to extract the ISRCS!",
                     "Isrcsubmit can work with one of the following:",
-                    "  " + ", ".join(backend))
+                    "  " + ", ".join(BACKENDS))
         sys.exit(-1)
 
     return backend
@@ -410,7 +410,7 @@ def open_browser(url, exit=False, submit=False):
                 else:
                     with open(os.devnull, "w") as devnull:
                         Popen([options.browser, url], stdout=devnull)
-            except FileNotFoundError as err:
+            except OSError as err:
                 error = ["Couldn't open the url in %s: %s"
                             % (options.browser, str(err))]
                 if submit:
@@ -549,7 +549,7 @@ def ask_for_submission(url, print_url=False):
         submit_requested = True
     else:
         printf("Would you like to open the browser to submit the disc?")
-        submit_requested = user_input(" [y/N] ") == "y"
+        submit_requested = user_input(" [y/N] ").lower() == "y"
 
     if submit_requested:
         open_browser(url, exit=True, submit=True)
@@ -997,7 +997,8 @@ def check_global_duplicates(release, mb_tracks, isrcs):
     if duplicates > 0:
         printf("\nThere were %d ISRCs ", duplicates)
         print("that are attached to multiple tracks on this release.")
-        if user_input("Do you want to help clean those up? [y/N] ") == "y":
+        choice = user_input("Do you want to help clean those up? [y/N] ")
+        if choice.lower() == "y":
             cleanup_isrcs(release, isrcs)
 
 def cleanup_isrcs(release, isrcs):
@@ -1037,7 +1038,7 @@ def cleanup_isrcs(release, isrcs):
                     print("")
 
             url = "http://%s/isrc/%s" % (options.server, isrc)
-            if user_input("Open ISRC in the browser? [Y/n] ") != "n":
+            if user_input("Open ISRC in the browser? [Y/n] ").lower() != "n":
                 open_browser(url)
                 user_input("(press <return> when done with this ISRC) ")
 
@@ -1060,11 +1061,13 @@ def main(argv):
         stream_handler.setLevel(logging.INFO)
 
         # adding log file
-        file_handler = logging.FileHandler("isrcsubmit.log", mode='w',
+        logfile = "isrcsubmit.log"
+        file_handler = logging.FileHandler(logfile, mode='w',
                             encoding="utf8", delay=True)
         formatter = logging.Formatter("%(levelname)s:%(name)s: %(message)s")
         file_handler.setFormatter(formatter)
         file_handler.setLevel(logging.DEBUG)
+        logger.info("Writing debug log to %s" % logfile)
         logging.getLogger().addHandler(file_handler)
 
         # add context to log file (DEBUG only added there)
@@ -1107,7 +1110,7 @@ def main(argv):
     else:
         if errors > 0:
             print_error("%d problems detected" % errors)
-        if user_input("Do you want to submit? [y/N] ") == "y":
+        if user_input("Do you want to submit? [y/N] ").lower() == "y":
             ws2.submit_isrcs(tracks2isrcs)
         else:
             update_intention = False
